@@ -236,11 +236,8 @@ sub getAPClientLoad
 		{
 			my $snmp_line = trim($line);
 			my $apMACAddress = trim(removeQuotes($snmp_line));
-			eval
-			{
-				$apList->getAccessPointByMACAddress($apMACAddress)->{clients} += 1;
-			};
-			# if ($@)	{ warn "AP with mac $apMACAddress not found\n"; }
+
+			$apList->getAccessPointByMACAddress($apMACAddress)->{clients} += 1;
 		}
 	}
 }
